Bootstrap表单组件 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Form Elements Common form elements and layouts

Text Field
Password Field
Inline help text
Readonly field
Disable it!
Relative Sizing
Grid Sizing
Input with Icon
Tooltip and help button
?
Tag input

#### Text Area

Default

With Character Limit

Autosize

#### Masked Input

Date 99/99/9999

Phone (999) 999-9999

Product Key a*-999-a999

Eye Script ~9.99 ~9.99 999

#### Select Box

Default

Multiple

Chosen

Multiple
style: 1 2

### Checkboxes & Radio All Checkboxes, Radios and Switch Buttons Are Pure CSS

Checkbox
choice 1
choice 2
choice 3
disabled
Radio
radio option 1
radio option 2
radio option 3
disabled

On/Off Switches

#### Custom File Input

Allow only images

#### jQuery UI Sliders

77 55 33 40 88

#### Spinners

#### Date Picker

Date Picker

Date Range Picker

Time Picker

#### Color Picker

Color Picker

Custom Color Picker

#### Knob Input

#### Form Inside a Modal Box

#### Form Layouts

#### Default

Label name Example block-level help text here. check me out

#### Inline Forms

remember me

##### Search Form

#### Please fill the following form fields

Location
Username
Name
Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container